@@ -66,7 +66,7 @@ var otaLsCmd = &cobra.Command{
 		}
 		color.NoColor = viper.GetBool("no-color")
 
-		ota, err := ota.Open(filepath.Clean(args[0]))
+		ota, err := ota.Open(filepath.Clean(args[0]), viper.GetString("ota.key-val"))
 		if err != nil {
 			return fmt.Errorf("failed to open OTA file: %v", err)
 		}
